The Xarsed package is the beating heart of the Xarsed web app. This package contains all of the Xarsed computational modules. This has two benefits: it makes it easier to develop the web app and package in a centralized and separate manner, and it makes the capabilities of Xarsed available to everyone. Currently, you can perform various functions, including calculations of solar zenith and azimuth angles, calculations of photovoltaic module power, calculations of solar radiation on the surface of tilted and tracker panels, and ... with the help of the Xarsed package.